@@ -8,7 +8,7 @@ from typing import List, Type
 from uuid import UUID
 
 import sqlalchemy
-from pydantic import BaseModel
+from pydantic import BaseModel, JsonValue
 from sqlalchemy import create_engine
 from uuid6 import uuid7
 
@@ -496,6 +496,7 @@ class SqlcDispatcher(Dispatcher):
         arg_schema: Type[BaseModel] | None,
         task_config: TaskConfig,
         cron: str = None,
+        backfill: bool = True,
         source_code: str = None,
     ):
         with self.transaction() as conn:
@@ -563,6 +564,7 @@ class SqlcDispatcher(Dispatcher):
                         schedule=cron,
                         command=insert_task_command,
                         jobname=cron_job_name,
+                        should_backfill=backfill,
                     ),
                 )
             else:
@@ -857,7 +859,7 @@ class SqlcDispatcher(Dispatcher):
                 ),
             )
 
-    def get_result(self, task_id: UUID) -> dict:
+    def get_result(self, task_id: UUID) -> JsonValue:
         with self.transaction() as conn:
             result = fetch_result_sync(
                 conn, fetch_result.FetchResultParams(task_id=task_id)
